==> haskell-configurator-pg-0.2.10-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 configurator-pg
version:              0.2.10
visibility:           public
id:                   configurator-pg-0.2.10-HY37868ejJfCV3UuaixNkO
key:                  configurator-pg-0.2.10-HY37868ejJfCV3UuaixNkO
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  9f9e3b7137209e81cffebce90b8de611
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.10-HY37868ejJfCV3UuaixNkO
depends:
    base-4.17.2.1 containers-0.6.7
    megaparsec-9.6.1-KkOPmPbRCEmCvB2XbKT9En
    protolude-0.3.5-4OKktG4Zhpt44WPZ0dqSeX
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-pg-0.2.10-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 configurator-pg
version:              0.2.10
visibility:           public
id:                   configurator-pg-0.2.10-DTiJhrTd6E3OEaxQIVnXB
key:                  configurator-pg-0.2.10-DTiJhrTd6E3OEaxQIVnXB
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  79a3a7eefbf4a49b27c2fb98496f4aea
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.10-DTiJhrTd6E3OEaxQIVnXB
depends:
    base-4.17.2.1 containers-0.6.7
    megaparsec-9.6.1-EGAiipKGhRa2zjyQ3XtPp3
    protolude-0.3.5-3Ree5oM6YTH6ffLyGUhTbE
    scientific-0.3.7.0-43723I2k3fJ8FjtljY7WIm text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
